%% set inputs for solution below
%  The program produces responses to the shocks selected below under
%  irfshock. Paths for all the endogenous variables in the model selected
%  are produced. VariableName_difference holds the piece-wise linear solution for
%  VariableName.  VariableName_uncdifference holds the linear solution for
%  VariableName.

clear 
setpathdynare4

global M_ oo_

empty_var = [];
% list here any parameters to be overwritten -- leave only empty_var for all
% parameters at their default values specified in eggtrade_potential_param
save param_overwrite empty_var


modnam = 'eggtrade_potential';
modnamstar = 'eggtrade_potential_zlb';

constraint = 'rs<-(1/betap*pibar-1)';
constraint_relax ='rs>-(1/betap*pibar-1)';

% Pick innovation for IRFs
irfshock =char('errconshkp');      % label for innovation for IRFs

maxiter = 15;
tol0 = 1e-8;



% assign parameter values
eggtrade_potential_param;
eggtrade_potential_comp_param;
 
% assign steady state values
eggtrade_potential_set_ss


% Solve nonlinear model

SHOCKS = 1.2*[ -0.1 ] ;


shockssequence = SHOCKS;
nperiods = 30;



% Solve model, generate model IRFs
[zdatalinear zdatapiecewise zdatass oobase_ Mbase_  ] = ...
  solve_one_constraint(modnam,modnamstar,...
  constraint, constraint_relax,...
  shockssequence,irfshock,nperiods);


% unpack the IRFs                          
for i=1:M_.endo_nbr
  eval([deblank(M_.endo_names(i,:)),'_u=zdatalinear(:,i);']);
  eval([deblank(M_.endo_names(i,:)),'_p=zdatapiecewise(:,i);']);
  eval([deblank(M_.endo_names(i,:)),'_ss=zdatass(i);']);
end


%% Modify to plot IRFs and decision rules

% plot of experiment
figtitle = '';
legendlist = char('Initial baeline with ZLB','Initial baseline without ZLB');
titlelist = char('Home GDP','Home Policy Rate (level, AR)',...
                 'Home Absorption','Home Inflation (level, AR)',....
                 'Home Exports','Home Real Interest Rate (level, AR)',...
                 'Real Exchange Rate','Home Trade Balance (GDP share)');
             
yaxislabels = char('% dev. from s.s.','Percent',...
                   '% dev. from s.s.','Percent',...
                   '% dev. from s.s.','Percent',...
                   '% dev. from s.s.','P.p. dev. from s.s.');
startperiod = 1;
plotperiods = nperiods;
               
makechart(titlelist,legendlist,figtitle,yaxislabels,...
100*[gdp_p(startperiod:plotperiods),(rs_p(startperiod:plotperiods)+(1/betap*pibar-1))*4,...
     prabs_p(startperiod:plotperiods),(dpq_p(startperiod:plotperiods)+pibar-1)*4,...
     mgsnif_p(startperiod:plotperiods),(rs1_p(startperiod:plotperiods)+(1/betap-1))*4,...
     rerpq_p(startperiod:plotperiods),ntby_p(startperiod:plotperiods)],...
100*[gdp_u(startperiod:plotperiods),(rs_u(startperiod:plotperiods)+(1/betap*pibar-1))*4,...
     prabs_u(startperiod:plotperiods),(dpq_u(startperiod:plotperiods)+pibar-1)*4,...
     mgsnif_u(startperiod:plotperiods),(rs1_u(startperiod:plotperiods)+(1/betap-1))*4,...
     rerpq_u(startperiod:plotperiods),ntby_u(startperiod:plotperiods)]);

 
 
