%% set inputs for solution below
%  The program produces responses to the shocks selected below under
%  irfshock. Paths for all the endogenous variables in the model selected
%  are produced. VariableName_difference holds the piece-wise linear solution for
%  VariableName.  VariableName_uncdifference holds the linear solution for
%  VariableName.

clear 

setpathdynare4
global M_ oo_

betap = 0.9995;  
pibar = 1.00+0.3/400;

empty_var = [];
% list here any parameters to be overwritten -- leave only empty_var for all
% parameters at their default values specified in eggtrade_potential_param
save param_overwrite empty_var betap pibar


modnam = 'eggtrade_potential';
modnamstar = 'eggtrade_potential_zlb';

constraint = 'rs<-(1/betap*pibar-1)';
constraint_relax ='rs>-(1/betap*pibar-1)';

% Pick innovation for IRFs
irfshock =char('errconshkpf'); % label for innovation for IRFs

SHOCKS_for_experiment_cycle =  -0.042916092518532*[1   % will loop through each of these shocks
                                    2 
                                    4]; 

maxiter = 15;
tol0 = 1e-8;

nperiods = 30;


% assign parameter values
eggtrade_potential_param;
eggtrade_potential_comp_param;
 
% assign steady state values
eggtrade_potential_set_ss


% Solve nonlinear model

for this_shock = 1:length(SHOCKS_for_experiment_cycle)
shockssequence = SHOCKS_for_experiment_cycle(this_shock);

% Solve model, generate model IRFs
[zdatalinear zdatapiecewise zdatass oobase_ Mbase_  ] = ...
  solve_one_constraint(modnam,modnamstar,...
  constraint, constraint_relax,...
  shockssequence,irfshock,nperiods);


% unpack the IRFs                          
for i=1:M_.endo_nbr
  eval([deblank(M_.endo_names(i,:)),'_u',num2str(this_shock),'=zdatalinear(:,i);']);
  eval([deblank(M_.endo_names(i,:)),'_p',num2str(this_shock),'=zdatapiecewise(:,i);']);

end

end

% unpack steady states -- assumes parameters are constant across
% experiments
for i=1:M_.endo_nbr
    eval([deblank(M_.endo_names(i,:)),'_ss=zdatass(i);']);
end

%% Modify to plot IRFs and decision rules

% plot of experiment
figtitle = '';
legendlist = char('Foreign Shock','2 X Foreign Shock','4 X Foreign Shock');
titlelist = char('Home GDP','Foreign GDP',...
                 'Home Policy Rate (level, AR)','Home Absorption',...
                 'Home Real Interest Rate (level, AR)','Home Exports',...
                 'Real Exchange Rate','Home Trade Balance (GDP share)');
             
yaxislabels = char('% dev. from s.s.','% dev. from s.s.',...
                   'Percent','Percent',...
                   'Percent','% dev. from s.s.',...
                   '% dev. from s.s.','% dev. from s.s.');
startperiod = 1;
plotperiods = nperiods;
               
line1 = 100*[gdp_p1(startperiod:plotperiods),gdpf_p1(startperiod:plotperiods),...
     (rs_p1(startperiod:plotperiods)+(1/betap*pibar-1))*4,prabs_p1(startperiod:plotperiods),...
     mgsnif_p1(startperiod:plotperiods),(rs1_p1(startperiod:plotperiods)+(1/betap-1))*4,...
     rerpq_p1(startperiod:plotperiods),ntby_p1(startperiod:plotperiods)];
 
line2 = 100*[gdp_p2(startperiod:plotperiods),gdpf_p2(startperiod:plotperiods),...
     (rs_p2(startperiod:plotperiods)+(1/betap*pibar-1))*4,prabs_p2(startperiod:plotperiods),...
     mgsnif_p2(startperiod:plotperiods),(rs1_p2(startperiod:plotperiods)+(1/betap-1))*4,...
     rerpq_p2(startperiod:plotperiods),ntby_p2(startperiod:plotperiods)];
 
line3 = 100*[gdp_p3(startperiod:plotperiods),gdpf_p3(startperiod:plotperiods),...
     (rs_p3(startperiod:plotperiods)+(1/betap*pibar-1))*4,prabs_p3(startperiod:plotperiods),...
     mgsnif_p3(startperiod:plotperiods),(rs1_p3(startperiod:plotperiods)+(1/betap-1))*4,...
     rerpq_p3(startperiod:plotperiods),ntby_p3(startperiod:plotperiods)];
 

 
makechart(titlelist,legendlist,figtitle,yaxislabels,line1,line2,line3)
 

% plot of experiment
figtitle = '';
legendlist = char('Foreign Shock','2 X Foreign Shock','4 X Foreign Shock');
titlelist = char('Home GDP','Foreign GDP',...
                 'Home Policy Rate (level, AR)','Foreign Policy Rate (level, AR)');
             
yaxislabels = char('% dev. from s.s.','% dev. from s.s.',...
                   'Percent','Percent');
startperiod = 1;
plotperiods = nperiods;
               
line1 = 100*[gdp_p1(startperiod:plotperiods),gdpf_p1(startperiod:plotperiods),...
     (rs_p1(startperiod:plotperiods)+(1/betap*pibar-1))*4,(rsf_p1(startperiod:plotperiods)+(1/betap*pibar-1))*4];
 
line2 = 100*[gdp_p2(startperiod:plotperiods),gdpf_p2(startperiod:plotperiods),...
     (rs_p2(startperiod:plotperiods)+(1/betap*pibar-1))*4,(rsf_p2(startperiod:plotperiods)+(1/betap*pibar-1))*4];
 
line3 = 100*[gdp_p3(startperiod:plotperiods),gdpf_p3(startperiod:plotperiods),...
     (rs_p3(startperiod:plotperiods)+(1/betap*pibar-1))*4,(rsf_p3(startperiod:plotperiods)+(1/betap*pibar-1))*4];
 

 
[figure1, legend1]=makechart(titlelist,legendlist,figtitle,yaxislabels,line1,line2,line3)

set(legend1,...
    'Position',[0.463252314814817 0.00823093376284772 0.102369606973995 0.0645658517998944]);


inset_axes = axes('Parent',figure1,...
    'Position',[0.274726083401472 0.641483516483517 0.1586345053148 0.156593406593407]);

selector = [1 2 3 4 5];

plot(gdp_p1(selector)./gdpf_p1(selector),'k-','linewidth',1); hold on
plot(gdp_p2(selector)./gdpf_p2(selector),'r--','linewidth',1); 
plot(gdp_p3(selector)./gdpf_p3(selector),'b-.','LineWidth',1); 
set(inset_axes,'Xtick',[1 2 3 4 5])

xlim([1 5])
title('Ratio of Home \newline to Foreign GDP')
xlabel('Quarters')